@@ -19,17 +19,19 @@ creating the first AnyEvent watcher.
 
 package AnyEvent::Impl::EV;
 
+no warnings;
 use strict;
 
-use EV;
+use EV 3.44;
 
-sub time { EV::time }
-sub now  { EV::now  }
+sub time       { EV::time       }
+sub now        { EV::now        }
+sub now_update { EV::now_update }
 
 sub timer {
    my ($class, %arg) = @_;
 
-   EV::timer $arg{after}, 0, $arg{cb}
+   EV::timer $arg{after}, $arg{interval}, $arg{cb}
 }
 
 sub io {
